.. raw:: html

  <div class="container-index">

Documentation of the SOMA tools
================================

.. raw:: html

        <!-- Block section -->
            <div class="row-fluid">
                <div class="span6 box">
                    <h2><a href="user_guide_tree/index.html">User Guide</a></h2>
                    <blockquote>The main documentation of all the proposed scripts.
                    </blockquote>
                </div>
                <div class="span6 box">
                    <h2><a href="api_tree/index.html">API</a></h2>
                    <blockquote>The exact API of all functions and classes, as given 
                        by the docstrings.
                    </blockquote>
                </div>
            </div>

            <div class="row-fluid">
                <div class="span6 box">
                    <h2><a href="developer_tree/index.html">Contributing</a></h2>
                    <blockquote>Useful information for advanced users.
                    </blockquote>
                </div>
            </div>


    </div>
